import { world, system } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { showForm } from "../functions/showForm"

export default {
  name: "leaderboard",
  description: "View the top player streaks.",
  aliases: ["streaks", "lb"],
  run: async(chat, player, args) => {
    player.sendMessage("§ePlease close chat screen to view leaderboards.")
    
    const leaderboard = JSON.parse(world.getDynamicProperty("streak_leaderboard") ?? "[]");
  
  let currentPage = 1;
const pageSize = 5;

const totalPages = Math.ceil(leaderboard.length / pageSize);

function showPage() {
  const form = new ActionFormData();
  form.title("stk.lb:Leaderboard");
  form.body(`Page ${currentPage} of ${totalPages}`);

  const start = (currentPage - 1) * pageSize;
  const end = start + pageSize;
  const pageItems = leaderboard.slice(start, end);

  
  for (let i = 0; i < pageSize; i++) {
  const item = leaderboard[start + i];
  const rank = (currentPage - 1) * pageSize + i + 1;

  if (item) {
    const color = rank === 1 ? "§e" : rank === 2 ? "§7" : rank === 3 ? "§n" : "§r";
    const label = `${color}#${rank} ${item.name}:/:§r${item.streak}:/:${rank === 1 ? "Gold" : rank === 2 ? "Silver" : rank === 3 ? "Bronze" : "Default"}`;
    form.button(label, fireIcon(item.streak));
  } else {
    form.button(`§r:/:§r:/:§r`); 
  }
}

  const prevLabel = (currentPage === 1 || totalPages === 1) ? "Disabled" : "Previous";
  const nextLabel = (currentPage === totalPages || totalPages === 1) ? "Disabled" : "Next";

  form.button(prevLabel);
  form.button(nextLabel);

 system.run(() => {
  showForm(player, form).then(response => {
    if (response.canceled) return;

    if (response.selection === 5 && prevLabel !== "Disabled") {
      currentPage--;
      showPage();
    } else if (response.selection === 6 && nextLabel !== "Disabled") {
      currentPage++;
      showPage();
    }
  });
 })
}

  showPage()
  }
};

function fireIcon(streak) {
  const fire = "textures/ext/fire/";
  
  if(streak >= 300) {
    return fire + "gold";
  } else if(streak >= 200) {
    return fire + "blue";
  } else if(streak >= 100) {
    return fire + "purple";
  } else if(streak >= 30) {
    return fire + "magenta";
  } else if(streak >= 10) {
    return fire + "red";
  } else {
  return fire + "default";
  }
}