import { world, system, CommandPermissionLevel as Permission } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { rewardChest, weeklyChest, questChest } from "../variables/chests";
import { cap } from "../functions/formatString";
import { Command } from "../structures/Command";

export default {
  data: new Command()
  .setName("chests")
  .setDescription("View your chests list.")
  .setPermission(Permission.Any),
  run: (system, {source: player}, args) => {
    
    let chests = JSON.parse(player.getDynamicProperty("chests") ?? "{}");

    if (!chests.reward && !chests.quest && !chests.weekly) {
      chests = {
        reward: 0,
        quest: 0,
        weekly: 0
      };
    }
      
      const eavl = (key) => {
        if(chests[key] > 0) {
          return "avl";
        } else {
          return "una";
        }
      }
      
      const cform = new ActionFormData()
      .title("stk.chests:Your Chests")
      .button(`Weekly Chest:/:x${chests.weekly}`, "textures/ext/chests/weekly")
      .button(`x1:/:${eavl("weekly")}`)
      .button(`All:/:${eavl("weekly")}`)
      .button(`Reward Chest:/:x${chests.reward}`, "textures/ext/chests/reward")
      .button(`x1:/:${eavl("reward")}`)
      .button(`All:/:${eavl("reward")}`)
      .button(`Quest Chest:/:x${chests.quest}`, "textures/ext/chests/quest")
      .button(`x1:/:${eavl("quest")}`)
      .button(`All:/:${eavl("quest")}`)
      
      
  system.run(() => {
  function mainForm() {  
  cform.show(player).then((r) => {
        if(r.canceled) return;
        
      const list = {
  reward: rewardChest,
  weekly: weeklyChest,
  quest: questChest
}

const listname = ["", "weekly", "weekly", "", "reward", "reward", "", "quest", "quest"]

    const listItems = new ActionFormData()
    .title(`stk.list:${cap(listname[r.selection])} Chest`)
    .button("Spin")
    
    for(let a of list[listname[r.selection]]) {
      const col = rarityColor(a.rarity)
      listItems.button(`${col}${a.item}:/:x${a.amount}:/:§r${col}${a.rarity}`, a.texture ?? `textures/items/${a.typeId}`)
    }
    
    listItems.button("Back")
    
    listItems.show(player).then((rs) => {
      if(rs.canceled) return;
      if(rs.selection === 11) {
        mainForm()
       return;
      }
      
      if(rs.selection !== 0) return;
      const openAll = r.selection % 3 === 2;

let wasCanceled = false;
const receivedSummary = {};

function spinChestLoop(timesLeft) {
  if (timesLeft <= 0) {
    if (wasCanceled) player.sendMessage("§7Skipped. Remaining rewards were claimed.");
    player.runCommand("stopsound @s stk.spin");

    if (Object.keys(receivedSummary).length > 0) {
      const summary = Object.entries(receivedSummary).map(([key, info]) => {
        const col = rarityColor(info.rarity);
        return `§r§b- ${info.count}x ${col}${info.item}`;
      }).join("\n");
      player.sendMessage(`§l§aYou received:\n${summary}`);
    }

    return;
  }

  const newarr = rarityShuffle(list[listname[r.selection]]);
  const chosen = newarr[2];

  const key = chosen.item;
  if (!receivedSummary[key]) {
    receivedSummary[key] = {
      count: 0,
      rarity: chosen.rarity,
      item: chosen.item,
    };
  } else {
    receivedSummary[key].rarity = Math.min(receivedSummary[key].rarity, chosen.rarity);
  }
  receivedSummary[key].count += chosen.amount;

  const giveChosenReward = () => {
    player.runCommand(`give @s ${chosen.typeId} ${chosen.amount}`);
    chests[listname[r.selection]]--;
    player.setDynamicProperty("chests", JSON.stringify(chests));
  };

  if (wasCanceled) {
    giveChosenReward();
    spinChestLoop(timesLeft - 1);
    return;
  }

  const form = new ActionFormData()
    .title(`stk.spin:${cap(listname[r.selection])} Chest`)
    .button(timesLeft === 1 ? "Claim" : "Next Chest");

  for (let a of newarr) {
    const col = rarityColor(a.rarity);
    form.button(`x${a.amount} ${col}${a.item}`, a.texture ?? `textures/items/${a.typeId}`);
  }

  player.playSound("stk.spin", { volume: 0.5 });

  form.show(player).then((res) => {
    giveChosenReward();

    if (res.canceled) {
      wasCanceled = true;
      spinChestLoop(timesLeft - 1);
      return;
    }

    if (chests[listname[r.selection]] > 0 && timesLeft > 1) {
      spinChestLoop(timesLeft - 1);
    } else {
      spinChestLoop(0);
    }
  });
}


spinChestLoop(openAll ? chests[listname[r.selection]] : 1);
    })
      })
 }
  mainForm()  
  })
  
  return { status: 0 }; 
  }
}

function rarityColor(rarity) {
  if (rarity <= 0.3) return "§6"; 
  if (rarity <= 0.9) return "§d"; 
  if (rarity <= 1.7) return "§9"; 
  if (rarity <= 2.5) return "§a"; 
  return "§f"; 
}


function rarityShuffle(array) {
  const pool = array.slice();

  const result = [];

  while (pool.length > 0) {
    const totalRarity = pool.reduce((sum, obj) => sum + obj.rarity, 0);

    let roll = Math.random() * totalRarity;

    for (let i = 0; i < pool.length; i++) {
      roll -= pool[i].rarity;
      if (roll <= 0) {
        result.push(pool[i]);
        pool.splice(i, 1); 
        break;
      }
    }
  }

  return result;
}