import { commandRegistry } from "./index.js";
import { config } from "../variables/config";

export default {
  name: "help",
  aliases: ["h", "commands"],
  description: "Lists all available commands or info about a specific command.",
  params: "[command]",
  run: async (chat, player, args, db) => {
    if (args.length > 0) {
      const query = args[0].toLowerCase();
      const cmd = commandRegistry.find(c =>
        c.name === query || (c.aliases && c.aliases.includes(query))
      );

      if (!cmd || cmd.name === "help") {
        player.sendMessage(`§cNo help found for "${query}".`);
        return;
      }

      const aliasText = cmd.aliases?.length
        ? `§7Aliases: ${cmd.aliases.join(", ")}\n`
        : "";
      const descText = cmd.description ? `§f${cmd.description}\n` : "";
      const usageText = cmd.params ? `§8Usage: ${config.prefix}${cmd.name} ${cmd.params}\n` : "";

      player.sendMessage(`§eCommand: §6${cmd.name}\n${aliasText}${descText}${usageText}`);
      return;
    }

    let helpText = "§eAvailable Commands:\n";

    for (const cmd of commandRegistry) {
      if (cmd.name === "help") continue;

      const aliasText = cmd.aliases?.length
        ? `§7Aliases: ${cmd.aliases.join(", ")}\n`
        : "";
      const descText = cmd.description ? `§f${cmd.description}\n` : "";
      const usageText = cmd.params ? `§8Usage: ${config.prefix}${cmd.name} ${cmd.params}\n` : "";

      helpText += `§6- ${cmd.name}\n${aliasText}${descText}${usageText}\n`;
    }

    player.sendMessage(helpText.trim());
  }
};
