import { world, CommandPermissionLevel as Permission } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { cap, plural } from "../functions/formatString";
import { Command } from "../structures/Command";

export default {
  data: new Command()
  .setName("info")
  .setDescription("View your streak or another player's streak.")
  .addPlayerSelectorOption("player", false)
  .setPermission(0),
  run: (system, data, args) => {
    console.warn(Permission.Any, Permission.GameDirectors, Permission.Admin, Permission.Host, Permission.Owner)
    let target = data.source;
    
    if (args.length) {
      let players = args[0];
      let id = players[0].id;
   
      const found = world.getAllPlayers().find(p => p.id.toLowerCase() === id);
      if (!found) {
        data.source.sendMessage(`§cPlayer does not exist or is offline.`);
        return;
      }
      target = found;
    }

    const currentStreak = target.getDynamicProperty("streak") || 0;
    const highestStreak = target.getDynamicProperty("stk.highest") || 0;
    const lastActive = target.getDynamicProperty("lastActive") || new Date().toLocaleDateString();

    const leaderboard = JSON.parse(world.getDynamicProperty("streak_leaderboard") ?? "[]");
    leaderboard.sort((a, b) => b.streak - a.streak);
    const playerIndex = leaderboard.findIndex(entry => entry.name === target.name);
    
    const rankTitle = playerIndex === 0 ? "Gold" : playerIndex === 1 ? "Silver" : playerIndex === 2 ? "Bronze" : "Regular";

    const form = new ActionFormData()
      .title(`stk.info:${rankTitle}`)
      .button(`${target.name}`)
      .button(`§r${currentStreak}`, fireIcon(currentStreak))
      .button(`§r${highestStreak}`, fireIcon(highestStreak))
      .button(`§r${lastActive}`)
      .button(streakBorder(currentStreak), target.id)

    system.run(() => {
      form.show(data.source);
    });
  }
}

function streakBorder(streak) {
  const border = "textures/ext/info/border/";
  if (streak >= 300) return border + "gold";
  if (streak >= 200) return border + "blue";
  if (streak >= 100) return border + "purple";
  if (streak >= 30) return border + "magenta";
  if (streak >= 10) return border + "red";
  return border + "default";
}

function fireIcon(streak) {
  const fire = "textures/ext/fire/";
  if (streak >= 300) return fire + "gold";
  if (streak >= 200) return fire + "blue";
  if (streak >= 100) return fire + "purple";
  if (streak >= 30) return fire + "magenta";
  if (streak >= 10) return fire + "red";
  return fire + "default";
}
