import { ActionFormData } from "@minecraft/server-ui";
import { cap, plural } from "../functions/formatString";
import { world, CommandPermissionLevel as Permission } from "@minecraft/server";
import { Command } from "../structures/Command";


export default {
  data: new Command()
  .setName("quests")
  .setDescription("Show lists of task daily.")
  .setPermission(Permission.Any),
 run: (system, {source: player}, args) => {
   const config = JSON.parse(world.getDynamicProperty("stk.config") ?? "{}");

    if (config.quest === false) {
      player.sendMessage("§cThe quest system is currently disabled in this world.");
      return; 
    }
   
      const tasks = JSON.parse(player.getDynamicProperty("quest.list") ?? "[]");

let completed = tasks.filter(t => t.completed).length;

let percent = tasks.length > 0 ? Math.round((completed / tasks.length) * 100) : 0;

    const form = new ActionFormData()
     .title("stk.sfq:Daily Quests")
     .body(`${percent}§l${completed}/${tasks.length}`)
     
     for(let task of tasks) {
      form.button(`${cap(task.category)} ${task.amount} ${plural(task.typeId, task.amount).replaceAll("_", " ")}${task.category === "shoot" ? " with an arrow " : " "}(${task.current}/${task.amount}):/:${task.completed ? "complete" : "incomplete"}`)
     }
     
    const claimed = player.getDynamicProperty("quest.claimed") 
     
     form.button(`${claimed ? "Claimed" : completed >= 3 ? "Claim" : "In Progress"}`)
   
   system.run(() => {
    form.show(player).then((r) => {
    if(r.canceled) return;
      
      let chests = JSON.parse(player.getDynamicProperty("chests") ?? "{}");

    if (!chests.reward && !chests.quest && !chests.weekly) {
      chests = {
        reward: 0,
        quest: 0,
        weekly: 0
      };
    }
    
    chests.quest = (chests.quest ?? 0) + 1;
    
    player.setDynamicProperty("chests", JSON.stringify(chests));
    player.setDynamicProperty("quest.claimed", true)
    player.playSound("random.levelup")
    
    const upForm = new ActionFormData()
    .title("stk.sfq:Daily Quests")
    .body(`${percent}§l${completed}/${tasks.length}`)
    
    for(let task of tasks) {
      upForm.button(`${cap(task.category)} ${task.amount} ${plural(task.typeId, task.amount).replaceAll("_", " ")}${task.category === "shoot" ? " with an arrow " : " "}(${task.current}/${task.amount}):/:completed`)
     }
    
     upForm.button(`Claimed`)
    
    upForm.show(player)
     })
   })
  }
}