import { system, world } from "@minecraft/server";
import { milestoneRewards } from "../variables/milestoneRewards";

const fire = {
     original: "",
     red: "",
     magenta: "",
     purple: "",
     blue: "",
     gold: ""
   }

export default {
  name: "playerSpawn",
  type: 1,
  run: async (data) => {
    if (!data.initialSpawn) return;

   const config = JSON.parse(world.getDynamicProperty("stk.config") ?? "{}");

   if(config.nameTag !== false) {
    data.player.nameTag = `${fire.original} §8§l| §r${data.player.name}`;
   }
   
    const now = new Date().toLocaleDateString();

    let streak = data.player.getDynamicProperty("streak") ?? 0;
    let lastActive = data.player.getDynamicProperty("lastActive");

    if (!lastActive) {
      data.player.setDynamicProperty("lastActive", now);
      lastActive = now;
    }

    if (lastActive !== now) {
      await system.waitTicks(20);
    data.player.onScreenDisplay.setTitle(`stk.display:§r-`)
    
    await system.waitTicks(180);
      const diff = (new Date(now) - new Date(lastActive)) / (1000 * 60 * 60 * 24);

      if (streak !== 0 && Math.floor(diff) > 1) {
        streak = 0;
        data.player.onScreenDisplay.setTitle(`stk.toast:Streak Destroyed!:/:§r${streak}-Day Streak:/:Off`);
        
        await system.waitTicks(2);
        data.player.playSound("random.glass");
      } else {
        streak++;
        data.player.onScreenDisplay.setTitle(`stk.toast:Streak Up!:/:§r${streak}-Day Streak:/:${fireLogo(streak)}`);
        await system.waitTicks(2);
        data.player.playSound("random.levelup");
      }

      data.player.setDynamicProperty("streak", streak);
      data.player.setDynamicProperty("lastActive", now);
      
      await system.waitTicks(200);
   
   const highestStreak = data.player.getDynamicProperty("stk.highest") 
    if(!highestStreak || streak >= highestStreak) {
      data.player.setDynamicProperty("stk.highest", streak)
    }

    data.player.onScreenDisplay.setTitle(`stk.display:§r${streak}`);
    } else {
      await system.waitTicks(20);
   
   const highestStreak = data.player.getDynamicProperty("stk.highest") 
    if(!highestStreak || streak >= highestStreak) {
      data.player.setDynamicProperty("stk.highest", streak)
    }

    data.player.onScreenDisplay.setTitle(`stk.display:§r${streak}`);
    }
    

    if(config.nameTag !== false) {
    data.player.nameTag = `§l§6${streak}${fireIcon(streak)} §8| §r${data.player.name}`;
    }
    
    const leaderboard = JSON.parse(world.getDynamicProperty("streak_leaderboard") ?? "[]");
    const playerName = data.player.name;

    const existing = leaderboard.find((entry) => entry.name === playerName);
    if (existing) {
      existing.streak = streak;
    } else {
      leaderboard.push({ name: playerName, streak });
    }

    world.setDynamicProperty("streak_leaderboard", JSON.stringify(leaderboard));

    if (config.reward === false) return; 
 
    const rewardAmount = milestoneRewards[streak];
    
    if (rewardAmount) {
      const claimDate = data.player.getDynamicProperty("stk.reward.claimed") || now;
      
      if(claimDate === now) return;
      
      const chests = JSON.parse(data.player.getDynamicProperty("chests") ?? "{}");
    
      chests.reward = (chests.reward ?? 0) + rewardAmount;
    
      data.player.setDynamicProperty("chests", JSON.stringify(chests));
      data.player.setDynamicProperty('stk.reward.claimed', now)
     
      data.player.sendMessage(`§bYou've earned §l§a${rewardAmount}§r§b reward chest(s) for reaching a ${streak}-day streak!`);
    }
  }
};

function fireIcon(streak) {
  if(streak >= 300) {
    return fire.gold;
  } else if(streak >= 200) {
    return fire.blue;
  } else if(streak >= 100) {
    return fire.purple;
  } else if(streak >= 30) {
    return fire.magenta;
  } else if(streak >= 10) {
    return fire.red;
  } else {
    return fire.original;
  }
}

function fireLogo(streak) {
  if(streak >= 300) {
    return "Gold";
  } else if(streak >= 200) {
    return "Blue";
  } else if(streak >= 100) {
    return "Purple";
  } else if(streak >= 30) {
    return "Magenta";
  } else if(streak >= 10) {
    return "Red";
  } else {
    return "Original";
  }
}