import { Player, world, system } from "@minecraft/server";
import { cap, plural } from "../functions/formatString";

export default {
  name: "entityDie",
  type: 1,
  run: async ({ damageSource, deadEntity }) => {
    const player = damageSource.damagingEntity;
    if (!(player instanceof Player)) return;

    const config = JSON.parse(world.getDynamicProperty("stk.config") ?? "{}");

    if (config.quest === false) return; 

    const questListRaw = player.getDynamicProperty("quest.list");
  
    if (!questListRaw) return;

    const questList = JSON.parse(questListRaw);
    let updated = false;

    questList.forEach((quest, index) => {
      if (quest.category !== "kill" || ("minecraft:" + quest.typeId) !== deadEntity.typeId || quest.completed) return;

      if(quest.current < quest.amount) {
        quest.current++;

        if(quest.current >= quest.amount) {
          quest.completed = true;
          
         const desc = `${cap(quest.category)} ${quest.amount} ${plural(quest.typeId, quest.amount).replaceAll("_", " ")}${quest.category === "shoot" ? " with an arrow " : " "}`
          
          system.run(async() => {
          player.playSound("random.levelup")
          await system.waitTicks(2)
          player.onScreenDisplay.setTitle(`stk.toast:Quest Complete!:/:${desc}:/:Complete`)
          })
        }

        updated = true;
      }
    });

    if(updated) {
      player.setDynamicProperty("quest.list", JSON.stringify(questList));
    }
  }
};
