import { cap, plural } from "../functions/formatString";
import { system, world } from "@minecraft/server"

export default {
  name: "playerPlaceBlock",
  type: 0,
  run: async(data) => {
    const config = JSON.parse(world.getDynamicProperty("stk.config") ?? "{}");
    
    if (config.quest === false) return; 
    
    const questListRaw = data.player.getDynamicProperty("quest.list");
  
    if (!questListRaw) return;
    const questList = JSON.parse(questListRaw);
    let updated = false;

    questList.forEach((quest, index) => {
      
      if(quest.category !== "place" || ("minecraft:" + quest.typeId) !== data.permutationBeingPlaced.type.id || quest.completed) return;

      if(quest.current < quest.amount) {
        quest.current++;

        if(quest.current >= quest.amount) {
          quest.completed = true;
          
          const desc = `${cap(quest.category)} ${quest.amount} ${plural(quest.typeId, quest.amount).replaceAll("_", " ")}${quest.category === "shoot" ? " with an arrow " : " "}`
          
          system.run(async() => {
            data.player.playSound("random.levelup")
          await system.waitTicks(2)
          data.player.onScreenDisplay.setTitle(`stk.toast:Quest Complete!:/:${desc}:/:Complete`)
          })
        }

        updated = true;
      }
    });

    if(updated) {
      data.player.setDynamicProperty("quest.list", JSON.stringify(questList));
    }
  }
}