import { Player, system, world } from "@minecraft/server";
import { cap, plural } from "../functions/formatString";

export default {
  name: "projectileHitEntity",
  type: 1,
  run: async(data) => {
    if(!(data.source instanceof Player)) return;
    if(data.projectile.typeId !== "minecraft:arrow") return;
    
    const config = JSON.parse(world.getDynamicProperty("stk.config") ?? "{}");

    if (config.quest === false) return; 
    
    const entity = data.getEntityHit().entity;

  const questListRaw = data.source.getDynamicProperty("quest.list");
  
    if (!questListRaw) return;

    const questList = JSON.parse(questListRaw);
    let updated = false;

    questList.forEach((quest, index) => {
      if (quest.category !== "shoot" || ("minecraft:" + quest.typeId) !== entity.typeId || quest.completed) return;

      if(quest.current < quest.amount) {
        quest.current++;

        if(quest.current >= quest.amount) {
          quest.completed = true;
          
          const desc = `${cap(quest.category)} ${quest.amount} ${plural(quest.typeId, quest.amount).replaceAll("_", " ")}${quest.category === "shoot" ? " with an arrow " : " "}`
          
          system.run(async() => {
            data.source.playSound("random.levelup")
          await system.waitTicks(2)
          data.source.onScreenDisplay.setTitle(`stk.toast:Quest Complete!:/:${desc}:/:Complete`)
          })
        }

        updated = true;
      }
    });

    if(updated) {
      data.source.setDynamicProperty("quest.list", JSON.stringify(questList));
    }
  }
}